marktools.is_component_with_lilypond_comment_attached
=====================================================

.. autofunction:: abjad.tools.marktools.is_component_with_lilypond_comment_attached.is_component_with_lilypond_comment_attached
